@@ -10,7 +10,7 @@ extends 'App::SimulateReads::CLI';
 
 with 'App::SimulateReads::Role::ParseArgv';
 
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 has 'command_stack' => (
 	traits  => ['Array'],
@@ -40,6 +40,11 @@ sub _build_app_path {
 	return $INC{$command_pm};
 }
 
+override 'opt_spec' => sub {
+	super,
+	'version|v'
+};
+
 sub command_map_bultin {
 	help => \&help_command,
 	man  => \&man_command
@@ -69,6 +74,11 @@ sub _try_msg {
 	return sprintf "Try '%s --help' for more information" => $self->_whois;
 }
 
+sub _version_text {
+	my $self = shift;
+	pod2usage(-verbose => 99, -sections => ['NAME', 'VERSION'], -exitval => 0);
+}
+
 sub _help_text {
 	my ($self, $path) = @_;
 	$path ||= $self->app_path;
@@ -113,6 +123,7 @@ sub run_no_command {
 
 	$self->_help_text if $opts->{help};
 	$self->_man_text if $opts->{man};
+	$self->_version_text if $opts->{version};
 }
 
 sub run_command {
@@ -241,7 +252,7 @@ App::SimulateReads::CLI::App - App::SimulateReads::CLI subclass for command line
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
